'The attached Code or Example is provided As Is.  
'It has not been tested or validated as a product, 
'for use in a deployed application or system, or for use in hazardous environments.  
'You assume all risks for use of the Code or Example.

Public Class Form1
    Dim Formloaded As Boolean = False
    Dim inventory As MccDaq.DaqDeviceDescriptor()
    Public Daqboard As New MccDaq.MccBoard()
    Dim ulstat As MccDaq.ErrorInfo
    Dim Status As Boolean
    Public AIMhandle As IntPtr
    Dim AINumPoints As Integer
    Dim numpoints As Integer
    Dim numchannels As Integer
    Dim LowChannelNumber, HighChannelNumber As Int32
    Dim AInScanRange As MccDaq.Range
    Dim ChannelCount As Integer

    Dim arrayindex As Integer
    Dim m2DRows As Integer
    Dim rows, cols As Integer
    Dim twoDData(,) As Double

    Const AllowedCharactersInt As String = "0123456789"
    Const AllowedCharactersFloat As String = "0123456789."

    Private Sub KeyPressService(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs, ByVal charSet As String)

        If Not charSet.Contains(e.KeyChar) AndAlso e.KeyChar <> ChrW(Keys.Back) Then
            e.Handled = True
        End If

    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        'First Lets make sure there's a USB-1808 plugged in:
        Dim Boardfound As Boolean = False

        MccDaq.DaqDeviceManager.IgnoreInstaCal() 'don't use information from InstaCal.

        System.Windows.Forms.Cursor.Current = Cursors.WaitCursor 'change cursor to wait.

        'load all the boards it can find
        inventory = MccDaq.DaqDeviceManager.GetDaqDeviceInventory(MccDaq.DaqDeviceInterface.Any)

        Dim numDevDiscovered As Integer = inventory.Length 'how many was that?

        If numDevDiscovered > 0 Then
            For boardNum As Integer = 0 To numDevDiscovered - 1

                Try
                    '    Create a new MccBoard object for Board and assign a board number 
                    '    to the specified DAQ device with CreateDaqDevice()
                    Daqboard = MccDaq.DaqDeviceManager.CreateDaqDevice(boardNum, inventory(boardNum))

                    If Daqboard.BoardName.Contains("1808") Then
                        Boardfound = True
                        Daqboard.FlashLED()
                        Exit For
                    Else
                        MccDaq.DaqDeviceManager.ReleaseDaqDevice(Daqboard)
                    End If
                Catch ule As MccDaq.ULException
                    MsgBox(ule.ErrorInfo.Message)
                End Try
            Next
        End If

        If Boardfound = False Then
            MsgBox("Device not found in system.  Please check wiring.", MsgBoxStyle.Critical, "No Board detected")
            End
        End If

        Dim mystring As String = Daqboard.BoardName.Substring(0, Daqboard.BoardName.Trim.Length) + _
            " found as board number: " + Daqboard.BoardNum.ToString
        Me.Text = mystring

        LoadComboBox(cmbAInScanRange)


        'Determine if the device is set for single ended or differential by the number of channels.
        Daqboard.BoardConfig.GetNumAdChans(numchannels)

        Formloaded = True

    End Sub

    Private Sub btnAInStartStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnAInStartStop.Click
        If btnAInStartStop.Text = "Start" Then
            btnAInStartStop.Text = "Stop"
            Status = True
            Me.Refresh()
            Call RunAdc()
        Else
            btnAInStartStop.Text = "Start"
            Status = False
            ulstat = Daqboard.StopBackground(MccDaq.FunctionType.AiFunction)
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then Stop
            lblAIMode.Text = "Idle"
            ulstat = MccDaq.MccService.WinBufFreeEx(AIMhandle) ' Free up memory for use by other programs
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then Stop
        End If
    End Sub

    Public Sub RunAdc()
        Dim AInOptions As MccDaq.ScanOptions

        Try
            Integer.TryParse(txtLowChannel.Text, LowChannelNumber)
        Catch
            MessageBox.Show(txtRate.Text + " is not a valid Low Channel Number value", "Invalid Channel Number ", _
            MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

        Try
            Integer.TryParse(txtHighChannel.Text, HighChannelNumber)
        Catch
            MessageBox.Show(txtRate.Text + " is not a valid High Channel Number value", "Invalid Channel Number ", _
            MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

        'set up sample count and redim arrays
        ChannelCount = HighChannelNumber - LowChannelNumber + 1

        Try
            Integer.TryParse(txtNumSamples.Text, AINumPoints)
            numpoints = AINumPoints
            AINumPoints = AINumPoints * ChannelCount
        Catch ex As Exception
            MessageBox.Show(txtNumSamples.Text + " is not a valid rate value", "Invalid Rate Number ", _
                        MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

        Dim ADRate As Int32
        Try
            Integer.TryParse(txtRate.Text, ADRate)
        Catch
            MessageBox.Show(txtRate.Text + " is not a valid number of points value", "Invalid count ", _
            MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

        AInScanRange = SelectRange(cmbAInScanRange.SelectedIndex)

        ' set aside memory to hold data
        AIMhandle = MccDaq.MccService.ScaledWinBufAllocEx(AINumPoints)
        If AIMhandle = 0 Then Stop

        'Set scan options
        AInOptions = MccDaq.ScanOptions.ScaleData

        'Start the scan
        lblAIMode.Text = "Running"
        lblAIMode.Refresh()
        ulstat = Daqboard.AInScan(LowChannelNumber, HighChannelNumber, AINumPoints, _
             ADRate, AInScanRange, AIMhandle, AInOptions)
        If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
            errhandler(ulstat)
            Exit Sub
        End If

        'In a foregroundscan, the program waits for the scan to complete before it continues
        'So the next line consumes or uses the gathered data.  I put it in a subroutine:
        ConvertData()

    End Sub

    Public Sub errhandler(ByVal ulstat As MccDaq.ErrorInfo)
        'Generic UL error handler
        MessageBox.Show(ulstat.Message, "Universal Library Error ", _
                   MessageBoxButtons.OK, MessageBoxIcon.Error)
        lblAIMode.Text = "Idle"
        btnAInStartStop.Text = "Start"
        ulstat = Daqboard.StopBackground(MccDaq.FunctionType.AiFunction)
        ulstat = MccDaq.MccService.WinBufFreeEx(AIMhandle) ' Free up memory for use by other programs
    End Sub

    Public Sub ConvertData()
        'Finally do something useful with the data.
        'Copy the data from the buffer to local array, then 
        'plot it in the oscilloscope.

        Dim ADDataV((ChannelCount) * (AINumPoints - 1)) As Double
        ReDim twoDData((ChannelCount - 1), (Math.Truncate(numpoints / ChannelCount) - 1))
        ulstat = MccDaq.MccService.ScaledWinBufToArray(AIMhandle, ADDataV, 0, numpoints)

        'Data returned from 'ScaledWinBufToArray' is in an interleaved 1D array. The oscilloscope
        'requires the data to be in a 2D array so here is how to 
        'convert the data from a 1D array to a 2D array so it can be plotted
        For cols = 0 To ChannelCount - 1
            m2DRows = -1
            For rows = 0 To numpoints - ChannelCount Step ChannelCount
                arrayindex = cols + rows
                m2DRows += 1
                twoDData(cols, m2DRows) = ADDataV(arrayindex)
            Next
        Next
        Oscilloscope11.UpdateScope(twoDData)     'twoDData is an array of new data to send to the oscilloscope.

        btnAInStartStop.Text = "Start"
        ulstat = Daqboard.StopBackground(MccDaq.FunctionType.AiFunction)
        lblAIMode.Text = "Idle"
        ulstat = MccDaq.MccService.WinBufFreeEx(AIMhandle) ' Free up memory for use by other programs
        If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
            errhandler(ulstat)
            Exit Sub
        End If

    End Sub

    Private Sub btnEnd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEnd.Click
        End
    End Sub

    Private Sub txtRate_KeyPress(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles txtRate.KeyPress
        KeyPressService(sender, e, AllowedCharactersInt)
    End Sub

    Public Sub LoadComboBox(ByVal sender As System.Object)
        With sender
            .Items.Add("BIP10VOLTS")
            .Items.Add("BIP5VOLTS")
            .Items.Add("UNI10VOLTS")
            .Items.Add("UNI5VOLTS")
            .SelectedIndex = 0
        End With
    End Sub

    Private Sub txtLowChannel_KeyPress(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles txtLowChannel.KeyPress
        KeyPressService(sender, e, AllowedCharactersInt)
    End Sub

    Private Sub txtHighChannel_KeyPress(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles txtHighChannel.KeyPress
        KeyPressService(sender, e, AllowedCharactersInt)
    End Sub

    Private Sub chkSeDiConfig_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles chkSeDiConfig.CheckedChanged
        If sender.checked Then
            sender.text = "Single Ended"
            ulstat = Daqboard.AInputMode(MccDaq.AInputMode.SingleEnded)
        Else
            sender.text = "Differential"
            ulstat = Daqboard.AInputMode(MccDaq.AInputMode.Differential)
        End If
    End Sub

    Public Function SelectRange(ByVal ComboBoxIndex As Int32) As Int32
        If Formloaded = False Then Exit Function
        Dim AInRange As Int32
        Select Case ComboBoxIndex
            Case 0
                AInRange = Convert.ToInt32([Enum].Parse(GetType(MccDaq.Range), MccDaq.Range.Bip10Volts))
                Oscilloscope11.YMaximum = 10                'enter the min, max, and number of ticks for the Y Scale
                Oscilloscope11.YMinimum = -10
                Oscilloscope11.YTicks = 10
            Case 1
                AInRange = Convert.ToInt32([Enum].Parse(GetType(MccDaq.Range), MccDaq.Range.Bip5Volts))
                Oscilloscope11.YMaximum = 5                'enter the min, max, and number of ticks for the Y Scale
                Oscilloscope11.YMinimum = -5
                Oscilloscope11.YTicks = 10

            Case 2
                AInRange = Convert.ToInt32([Enum].Parse(GetType(MccDaq.Range), MccDaq.Range.Uni10Volts))
                Oscilloscope11.YMaximum = 10                'enter the min, max, and number of ticks for the Y Scale
                Oscilloscope11.YMinimum = 0
                Oscilloscope11.YTicks = 10
            Case 3
                AInRange = Convert.ToInt32([Enum].Parse(GetType(MccDaq.Range), MccDaq.Range.Uni5Volts))
                Oscilloscope11.YMaximum = 5                'enter the min, max, and number of ticks for the Y Scale
                Oscilloscope11.YMinimum = 0
                Oscilloscope11.YTicks = 5
        End Select

        Return AInRange

    End Function
End Class
