﻿'The attached Code or Example is provided As Is.  
'It has not been tested or validated as a product, 
'for use in a deployed application or system, or for use in hazardous environments.  
'You assume all risks for use of the Code or Example.
Public Class Form1

    Dim inventory As MccDaq.DaqDeviceDescriptor()
    Public Daqboard As New MccDaq.MccBoard()
    Dim ulstat As MccDaq.ErrorInfo

    Dim MaxCounter As Integer = 7
    Dim Mode As MccDaq.CounterMode
    Dim CounterDebounceTime As MccDaq.CounterDebounceTime
    Dim CounterDebounceMode As MccDaq.CounterDebounceMode
    Dim CounterEdgeDetection As MccDaq.CounterEdgeDetection
    Dim myCounterTickSize As MccDaq.CounterTickSize
    Dim mappedChannel As Integer
    Dim MyCount As Integer
    Dim MccCounter As MccDaq.CounterRegister

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        'First, let's find a USB-1808
        MccDaq.DaqDeviceManager.IgnoreInstaCal() 'don't use information from InstaCal.

        System.Windows.Forms.Cursor.Current = Cursors.WaitCursor 'change cursor to wait.
        Dim Boardfound As Boolean = False

        'load all the boards it can find
        inventory = MccDaq.DaqDeviceManager.GetDaqDeviceInventory(MccDaq.DaqDeviceInterface.Any)

        Dim numDevDiscovered As Integer = inventory.Length 'how many was that?

        If numDevDiscovered > 0 Then
            For boardNum As Integer = 0 To numDevDiscovered - 1

                Try
                    '    Create a new MccBoard object for Board and assign a board number 
                    '    to the specified DAQ device with CreateDaqDevice()
                    Daqboard = MccDaq.DaqDeviceManager.CreateDaqDevice(boardNum, inventory(boardNum))

                    If Daqboard.BoardName.Contains("1808") Then
                        Boardfound = True
                        Daqboard.FlashLED()
                        Exit For
                    Else
                        MccDaq.DaqDeviceManager.ReleaseDaqDevice(Daqboard)
                    End If
                Catch ule As MccDaq.ULException
                    MsgBox(ule.ErrorInfo.Message)
                End Try
            Next
        End If

        If Boardfound = False Then
            MsgBox("No compatible board found in system.  Please run InstaCal.", MsgBoxStyle.Critical, "No Board detected")
            End
        End If

        Dim mystring As String = Daqboard.BoardName.Substring(0, Daqboard.BoardName.Trim.Length) + _
                  " found as board number: " + Daqboard.BoardNum.ToString
        Me.Text = mystring


        'Configure digital bit 0 for output if used to increment a counter manually
        ULStat = Daqboard.DConfigBit(MccDaq.DigitalPortType.AuxPort, 0, MccDaq.DigitalPortDirection.DigitalOut)
        lblULSTatus.Text = "UL Status: " + ULStat.Message

    End Sub

    Public Sub RunTotalizer()
        'Initializes the counter functions call totalize, clears the counters, starts the timer
        Mode = MccDaq.CounterMode.Totalize
        CounterDebounceTime = MccDaq.CounterDebounceTime.DebounceNone
        CounterDebounceMode = MccDaq.CounterDebounceMode.TriggerAfterStable
        CounterEdgeDetection = MccDaq.CounterEdgeDetection.RisingEdge
        myCounterTickSize = MccDaq.CounterTickSize.Tick20pt83ns
        mappedChannel = 0

        For i As Integer = 0 To MaxCounter
            MccCounter = SelectCounter(i)

            ulstat = Daqboard.CConfigScan(MccCounter, Mode, CounterDebounceTime, CounterDebounceMode, _
                 CounterEdgeDetection, myCounterTickSize, mappedChannel)
            lblULSTatus.Text = "UL Status: " + ulstat.Message

            ulstat = Daqboard.CLoad32(MccCounter, 0)
        Next

        If ulstat.Value = 0 Then
            lblModeStatus.Text = "Running"
            tmrTotalizerCounter.Enabled = True
        Else
            lblModeStatus.Text = "Idle"
            Exit Sub
        End If

    End Sub

    Public Function SelectCounter(ByVal nudCounterNumValue As Int32) As Int32
        'selects the correct counter register.
        Select Case nudCounterNumValue
            Case 0
                MccCounter = MccDaq.CounterRegister.LoadReg0
            Case 1
                MccCounter = MccDaq.CounterRegister.LoadReg1
        End Select

        Return MccCounter

    End Function

    Private Sub tmrEncoderCounter_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles tmrTotalizerCounter.Tick
        'Read all the counters and update the display.
        For i As Integer = 0 To MaxCounter
            MccCounter = SelectCounter(i)

            ulstat = Daqboard.CIn32(MccCounter, MyCount)
            lblULSTatus.Text = "UL Status: " + ulstat.Message
            Select Case i
                Case 0
                    lblCounterValue0.Text = MyCount
                Case 1
                    lblCounterValue1.Text = MyCount
            End Select
        Next
    End Sub

    Private Sub btnEnd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEnd.Click
        'end the program.
        tmrTotalizerCounter.Enabled = False
        End

    End Sub


    Private Sub btnTMRStartStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnTMRStartStop.Click
        '5 Hz timer out to stimulate any counter.
        If btnTMRStartStop.Text = "Start" Then
            btnTMRStartStop.Text = "Stop"
            ulstat = Daqboard.PulseOutStart(0, 5, 0.5, 0, 0, MccDaq.IdleState.Low, MccDaq.PulseOutOptions.Default)
        Else
            btnTMRStartStop.Text = "Start"
            ulstat = Daqboard.PulseOutStop(0)
        End If

    End Sub

    Private Sub btnStartStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnStartStop.Click
        'Start or stop reading alll the counters.
        If btnStartStop.Text = "Start" Then
            btnStartStop.Text = "Stop"
            Me.Refresh()
            Call RunTotalizer()
        Else
            btnStartStop.Text = "Start"
            tmrTotalizerCounter.Enabled = False

            lblModeStatus.Text = "Idle"
        End If

    End Sub

    Private Sub btnIncrementCounter_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnIncrementCounter.Click
        'Toggle digital bit 0 to increment any counter it is connected to.
        ulstat = Daqboard.DBitOut(MccDaq.DigitalPortType.AuxPort, 0, MccDaq.DigitalLogicState.High)
        ulstat = Daqboard.DBitOut(MccDaq.DigitalPortType.AuxPort, 0, MccDaq.DigitalLogicState.Low)
    End Sub

    Private Sub btnReset_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnReset.Click
        'Reset all counters to 0.
        For i As Integer = 0 To MaxCounter
            MccCounter = SelectCounter(i)

            ulstat = Daqboard.CLoad32(MccCounter, 0)
            ulstat = Daqboard.CIn32(MccCounter, MyCount)
            lblULSTatus.Text = "UL Status: " + ulstat.Message
            Select Case i
                Case 0
                    lblCounterValue0.Text = MyCount
                Case 1
                    lblCounterValue1.Text = MyCount
            End Select
        Next
    End Sub
End Class
