﻿'Disclaimer:
'This Example is provided As Is.  
'It has not been tested or validated as a product, 
'for use in a deployed application or system, or for use in hazardous environments.  
'You assume all risks for use of this Example or any part of the syntax contained herein.

Public Class Form1
    Dim inventory As MccDaq.DaqDeviceDescriptor()
    Public Daqboard As New MccDaq.MccBoard()
    Dim ulstat As MccDaq.ErrorInfo
    Dim Status As Boolean

    Dim NumCounter As Integer
    Dim Mode As MccDaq.CounterMode
    Dim CounterDebounceTime As MccDaq.CounterDebounceTime
    Dim CounterDebounceMode As MccDaq.CounterDebounceMode
    Dim CounterEdgeDetection As MccDaq.CounterEdgeDetection
    Dim myCounterTickSize As MccDaq.CounterTickSize
    Dim mappedChannel As Integer
    Dim lastcount As Integer
    Dim MccCounter As MccDaq.CounterRegister
    Dim MaxLimitRegister As MccDaq.CounterRegister

    Const AllowedCharactersInt As String = "0123456789"
    Const AllowedCharactersFloat As String = "0123456789."

    Private Sub KeyPressService(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs, ByVal charSet As String)

        If Not charSet.Contains(e.KeyChar) AndAlso e.KeyChar <> ChrW(Keys.Back) Then
            e.Handled = True
        End If

    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        'First,lets make sure there's some kind of 1808 plugged in:
        MccDaq.DaqDeviceManager.IgnoreInstaCal() 'don't use information from InstaCal.

        System.Windows.Forms.Cursor.Current = Cursors.WaitCursor 'change cursor to wait.
        Dim Boardfound As Boolean = False

        'load all the boards it can find
        inventory = MccDaq.DaqDeviceManager.GetDaqDeviceInventory(MccDaq.DaqDeviceInterface.Any)
        Dim numDevDiscovered As Integer = inventory.Length 'how many was that?

        If numDevDiscovered > 0 Then
            For boardNum As Integer = 0 To numDevDiscovered - 1

                Try
                    '    Create a new MccBoard object for Board and assign a board number 
                    '    to the specified DAQ device with CreateDaqDevice()
                    Daqboard = MccDaq.DaqDeviceManager.CreateDaqDevice(boardNum, inventory(boardNum))

                    If Daqboard.BoardName.Contains("1808") Then
                        Boardfound = True
                        Daqboard.FlashLED()
                        Exit For
                    Else
                        MccDaq.DaqDeviceManager.ReleaseDaqDevice(Daqboard)
                    End If
                Catch ule As MccDaq.ULException
                    MsgBox(ule.ErrorInfo.Message)
                End Try
            Next
        End If

        If Boardfound = False Then
            MsgBox("No compatible board found in system.", MsgBoxStyle.Critical, "No Board detected")
            End
        End If

        Dim mystring As String = Daqboard.BoardName.Substring(0, Daqboard.BoardName.Trim.Length) + _
                   " found as board number: " + Daqboard.BoardNum.ToString
        Me.Text = mystring

        With cmboMode
            .Items.Add("EncoderModeX1")
            .Items.Add("EncoderModeX2")
            .Items.Add("EncoderModeX4")
            .SelectedIndex = 0
        End With
    End Sub

    Private Sub btnStartStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnStartStop.Click
        If btnStartStop.Text = "Start" Then
            btnStartStop.Text = "Stop"
            Status = True
            Me.Refresh()
            Call runEncoder()
        Else
            btnStartStop.Text = "Start"
            Status = False
            tmrEncoderCounter.Enabled = False
            lblModeStatus.Text = "Idle"
        End If
    End Sub

    Public Sub runEncoder()
        ModeSetup()
        CounterDebounceTime = MccDaq.CounterDebounceTime.DebounceNone
        CounterDebounceMode = MccDaq.CounterDebounceMode.TriggerAfterStable
        CounterEdgeDetection = MccDaq.CounterEdgeDetection.RisingEdge
        myCounterTickSize = MccDaq.CounterTickSize.Tick200ns
        mappedChannel = 0
        MccCounter = SelectCounter(nudCounterNumber.Value)
        NumCounter = nudCounterNumber.Value

        ulstat = Daqboard.CConfigScan(MccCounter, Mode, CounterDebounceTime, CounterDebounceMode, _
             CounterEdgeDetection, myCounterTickSize, mappedChannel)
        lblULSTatus.Text = "UL Status: " + ulstat.Message
        If ulstat.Value = 0 Then
            lblModeStatus.Text = "Running"

            ulstat = Daqboard.CClear(MccCounter)

            tmrEncoderCounter.Enabled = True
        Else
            lblModeStatus.Text = "Idle"
            Exit Sub
        End If

    End Sub

    Public Sub ModeSetup()
        Mode = MccDaq.CounterMode.Encoder
        'Mode += MccDaq.CounterMode.Bit32

        Select Case cmboMode.SelectedIndex
            Case 0
                Mode += MccDaq.CounterMode.EncoderModeX1
            Case 1
                Mode += MccDaq.CounterMode.EncoderModeX2
            Case 2
                Mode += MccDaq.CounterMode.EncoderModeX4
        End Select

        'If any options are selected, enable it, and any other feature needed to make it operate.
        If rbuClearOnZOn.Checked Then Mode += MccDaq.CounterMode.EncoderModeClearOnZOn

        If rbuLatchOnZ.Checked Then Mode += MccDaq.CounterMode.EncoderModeLatchOnZ

        If rbuNoRecycleOn.Checked Then
            Mode += MccDaq.CounterMode.NoRecycleOn
            ulstat = Daqboard.CLoad(MaxLimitRegister, Convert.ToInt16(txtMaxLimitRegValue.Text))
            lblULSTatus.Text = "UL Status: " + ulstat.Message
        End If

        If rbuRangeLimitOn.Checked Then
            Mode += MccDaq.CounterMode.RangeLimitOn
            ulstat = Daqboard.CLoad(MaxLimitRegister, Convert.ToInt16(txtMaxLimitRegValue.Text))
            lblULSTatus.Text = "UL Status: " + ulstat.Message
        End If
    End Sub

    Private Sub btnCounterClear_Click(sender As System.Object, e As System.EventArgs) Handles btnCounterClear.Click
        'used with NoRecycleOn Mode.  This is how you clear the counter.
        ulstat = Daqboard.CClear(MccCounter)
    End Sub

    Private Sub tmrEncoderCounter_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles tmrEncoderCounter.Tick
        'with every timer tick, Read the counter.
        'Compare it to the last counter reading (value found in lastCount).
        'if there is no change, then show "STOPPED"
        'if there was a change, if MyCount is greater than lastcount, counter is counting up, show "UP",
        'If MyCount is less than lastcount, counter is counting down, show "DOWN".
        'Make MyCount the new lastcount, wait for next tick.....

        Dim MyCount As Integer

        ulstat = Daqboard.CIn32(MccCounter, MyCount)
        lblCounterValueRead.Text = MyCount
        If MyCount <> lastcount Then
            If MyCount > lastcount Then
                lblDirectionUD.Text = "UP"
            Else
                lblDirectionUD.Text = "DOWN"
            End If
        Else
            lblDirectionUD.Text = "STOPPED"
        End If

        lastcount = MyCount

    End Sub

    Public Function SelectCounter(ByVal nudCounterNumValue As Int32) As Int32
        'This example will let you use any one counter.  
        'If you want to use just one counter, just use the 2 lines for that counter
        'where you see "SelectCounter()".
        Select Case nudCounterNumValue
            'Case 0
            '    MccCounter = MccDaq.CounterRegister.LoadReg0
            '    MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg0
            'Case 1
            '    MccCounter = MccDaq.CounterRegister.LoadReg1
            '    MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg1
            Case 2
                MccCounter = MccDaq.CounterRegister.LoadReg2
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg2
            Case 3
                MccCounter = MccDaq.CounterRegister.LoadReg3
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg3
                'Case 4
                '    MccCounter = MccDaq.CounterRegister.LoadReg4
                '    MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg4
                'Case 5
                '    MccCounter = MccDaq.CounterRegister.LoadReg5
                '    MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg5
                'Case 6
                '    MccCounter = MccDaq.CounterRegister.LoadReg6
                '    MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg6
                'Case 7
                '    MccCounter = MccDaq.CounterRegister.LoadReg7
                '    MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg7
        End Select

        Return MccCounter
    End Function

    Private Sub btnEnd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEnd.Click
        End
    End Sub

    '******************************************************************************************************************
    '*Everything from here down is used to control how the program enables and disables features selected by you when *
    '*you run the program, or when you right click on a radio button (encoder option) or any CInScan option.          *
    '*You can ignore everything from here down, unless you want to see how I created the pop up help, etc.            *
    '******************************************************************************************************************

    Private Sub rbuLatchOnZ_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuLatchOnZ.CheckedChanged
        lblMaxLimitRegValue.Visible = False
        txtMaxLimitRegValue.Visible = False

        btnCounterClear.Visible = False
    End Sub

    Private Sub rbuClearOnZOn_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuClearOnZOn.CheckedChanged
        lblMaxLimitRegValue.Visible = False
        txtMaxLimitRegValue.Visible = False

        btnCounterClear.Visible = False
    End Sub

    Private Sub rbuRangeLimitOn_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuRangeLimitOn.CheckedChanged

        lblMaxLimitRegValue.Visible = True
        txtMaxLimitRegValue.Visible = True

        btnCounterClear.Visible = False

    End Sub

    Private Sub rbuNoRecycleOn_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuNoRecycleOn.CheckedChanged
        btnCounterClear.Visible = True

        lblMaxLimitRegValue.Visible = True
        txtMaxLimitRegValue.Visible = True
    End Sub

    Private Sub rbuModuloNOn_CheckedChanged(sender As System.Object, e As System.EventArgs)

        lblMaxLimitRegValue.Visible = True
        txtMaxLimitRegValue.Visible = True

        btnCounterClear.Visible = False

    End Sub

    Private Sub rbuNOP_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuNOP.CheckedChanged
        lblMaxLimitRegValue.Visible = False
        txtMaxLimitRegValue.Visible = False

        btnCounterClear.Visible = False

        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg0)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg1)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg2)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg3)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg4)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg5)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg6)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg7)

    End Sub

    Private Sub rbuLatchOnZ_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuLatchOnZ.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "Selects the Encoder Z mapped signal to latch the counter outputs. This allows the user to know the exact counter value when an edge is present on another counter."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuClearOnZOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuClearOnZOn.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "The counter is cleared on the rising edge of the Index (Z) input. By default, the ClearOnZ option is off, and the counter is not cleared."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuRangeLimitOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuRangeLimitOn.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "Enables Range Limit counting mode. In Range Limit mode, an upper and lower limit is set, mimicking limit switches in the mechanical counterpart." + _
                "The upper limit is set by loading the max limit register with the CLoad, CLoad32, or CLoad64 functions." + _
                "The lower limit is always 0. When counting up, the counter freezes whenever the count reaches the value that was loaded into the max limit register." + _
                vbCrLf + _
                vbCrLf + "Once selected a Text Box will appear where you can enter a value for the MaxCountReg Value."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuNoRecycleOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuNoRecycleOn.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "Enables Non-recycle counting mode. In Non-recycle mode, the counter is disabled whenever a count" + _
                "overflow or underflow takes place. The counter is re-enabled when a clear or a load operation is performed on the counter." + _
                vbCrLf + _
                vbCrLf + "Once selected a Clear/reset counter button and MaxCountReg box will appear."
            HelpInfo.Show(Me)
        End If
    End Sub

    'Private Sub rbuModuloNOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs)
    '    Dim MouseArgs As MouseEventArgs = e
    '    If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
    '        HelpInfo.txtHelpInfo.Text = "In Modulo-N mode, an upper limit is set by loading the max limit register with a maximum count. When counting up," + _
    '            " the counter will roll-over to 0 when the maximum count is reached, and then continue counting up. Likewise when counting down, " + _
    '            "the counter will roll over to the maximum count (in the max limit register) whenever the count reaches 0, and then continue counting down." + _
    '            vbCrLf + _
    '            vbCrLf + "Once selected a Text Box will appear where you can enter a value for the MaxCountReg Value."
    '        HelpInfo.Show(Me)
    '    End If
    'End Sub

    Private Sub rbuNOP_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuNOP.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "No Option:  sets the example to no options selected, and clears the MaxLimitRegister" 
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub txtMaxLimitRegValue_KeyPress(sender As System.Object, e As System.Windows.Forms.KeyPressEventArgs) Handles txtMaxLimitRegValue.KeyPress
        KeyPressService(sender, e, AllowedCharactersInt)
    End Sub
End Class
