﻿'The attached Code or Example is provided As Is.  
'It has not been tested or validated as a product, 
'for use in a deployed application or system, or for use in hazardous environments.  
'You assume all risks for use of the Code or Example.

Public Class Form1

    Dim inventory As MccDaq.DaqDeviceDescriptor()
    Public Daqboard As New MccDaq.MccBoard()
    Dim ulstat As MccDaq.ErrorInfo

    Dim Mode As MccDaq.CounterMode

    Dim MccCounter As MccDaq.CounterRegister
    Dim MaxLimitRegister As MccDaq.CounterRegister

    Dim numSamples As Integer
    Dim SamplingRate As Integer
    Dim CtrOptions As MccDaq.ScanOptions
    Public CTRHandle As IntPtr

    Dim CurIndex As Integer
    Dim CurCount As Integer
    Dim CTRStatus As Short

    'normally you will only use one of these:
    Dim usDataArray() As Short
    Dim uiDataArray() As UInteger
    Dim ulDataArray() As ULong

    Dim lastPass As String
    Dim Direction As Integer

    Const AllowedCharactersInt As String = "0123456789"
    Const AllowedCharactersFloat As String = "0123456789."

    Private Sub KeyPressService(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs, ByVal charSet As String)

        If Not charSet.Contains(e.KeyChar) AndAlso e.KeyChar <> ChrW(Keys.Back) Then
            e.Handled = True
        End If

    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        'First,lets make sure there's some kind of 1808 plugged in:
        MccDaq.DaqDeviceManager.IgnoreInstaCal() 'don't use information from InstaCal.

        System.Windows.Forms.Cursor.Current = Cursors.WaitCursor 'change cursor to wait.
        Dim Boardfound As Boolean = False

        'load all the boards it can find
        inventory = MccDaq.DaqDeviceManager.GetDaqDeviceInventory(MccDaq.DaqDeviceInterface.Any)
        Dim numDevDiscovered As Integer = inventory.Length 'how many was that?

        If numDevDiscovered > 0 Then
            For boardNum As Integer = 0 To numDevDiscovered - 1

                Try
                    '    Create a new MccBoard object for Board and assign a board number 
                    '    to the specified DAQ device with CreateDaqDevice()
                    Daqboard = MccDaq.DaqDeviceManager.CreateDaqDevice(boardNum, inventory(boardNum))

                    If Daqboard.BoardName.Contains("1808") Then
                        Boardfound = True
                        Daqboard.FlashLED()
                        Exit For
                    Else
                        MccDaq.DaqDeviceManager.ReleaseDaqDevice(Daqboard)
                    End If
                Catch ule As MccDaq.ULException
                    MsgBox(ule.ErrorInfo.Message)
                End Try
            Next
        End If

        If Boardfound = False Then
            MsgBox("No compatible board found in system.", MsgBoxStyle.Critical, "No Board detected")
            End
        End If

        Dim mystring As String = Daqboard.BoardName.Substring(0, Daqboard.BoardName.Trim.Length) + _
                   " found as board number: " + Daqboard.BoardNum.ToString
        Me.Text = mystring

        'some setup for so you can try different options.  
        With cmboMode
            .Items.Add("EncoderModeX1")
            .Items.Add("EncoderModeX2")
            .Items.Add("EncoderModeX4")
            .SelectedIndex = 0
        End With
    End Sub

    Private Sub btnStartStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnStartStop.Click
        '1 button to start and stop the scan
        If btnStartStop.Text = "Start" Then
            btnStartStop.Text = "Stop"
            lbRawCounterData.Items.Clear()
            Me.Refresh()
            Call runEncoder()
        Else
            btnStartStop.Text = "Start"
            tmrEncoderCounter.Enabled = False
            ulstat = Daqboard.StopBackground(MccDaq.FunctionType.CtrFunction)
            ulstat = MccDaq.MccService.WinBufFreeEx(CTRHandle) ' Free up memory for use by other programs
            lblModeStatus.Text = "Idle"
        End If
    End Sub

    Public Sub runEncoder()
        'Here is where the counters are configured..... 

        ModeSetup() 'this is called to sort the correct mode value 

        Dim CounterDebounceTime As MccDaq.CounterDebounceTime = MccDaq.CounterDebounceTime.DebounceNone
        Dim CounterDebounceMode As MccDaq.CounterDebounceMode = MccDaq.CounterDebounceMode.TriggerAfterStable
        Dim CounterEdgeDetection As MccDaq.CounterEdgeDetection = MccDaq.CounterEdgeDetection.RisingEdge
        Dim myCounterTickSize As MccDaq.CounterTickSize = MccDaq.CounterTickSize.Tick20pt83ns
        Dim mappedChannel As Integer = 0

        MccCounter = SelectCounter(nudCounterNumber.Value)

        ulstat = Daqboard.CConfigScan(MccCounter, Mode, CounterDebounceTime, CounterDebounceMode, _
             CounterEdgeDetection, myCounterTickSize, mappedChannel)
        If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
            errhandler(ulstat)
            Exit Sub
        End If

        numSamples = Convert.ToInt32(nudNumSamples.Value)
        SamplingRate = Convert.ToInt32(nudSamplingRate.Value)

        'counter options configuration
        CtrOptions = MccDaq.ScanOptions.Background

        If chkContinuous.Checked Then CtrOptions = CtrOptions + MccDaq.ScanOptions.Continuous
        If chkExtClock.Checked Then CtrOptions = CtrOptions + MccDaq.ScanOptions.ExtClock
        If chkExtTrigger.Checked Then CtrOptions = CtrOptions + MccDaq.ScanOptions.ExtTrigger
        If chkHighResRate.Checked Then CtrOptions = CtrOptions + MccDaq.ScanOptions.HighResRate

      
        CtrOptions += MccDaq.ScanOptions.Ctr32Bit
        CTRHandle = MccDaq.MccService.WinBufAlloc32Ex(numSamples * 2)
        ReDim uiDataArray(numSamples - 1)

        If CTRHandle = 0 Then Stop

        '....and the scan is launched
        ulstat = Daqboard.CInScan(MccCounter, MccCounter, numSamples * 2, SamplingRate, CTRHandle, CtrOptions)
        If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then 'If the scan did not start, find out why
            lblModeStatus.Text = "Idle"
            errhandler(ulstat)
            Exit Sub

        Else 'If the Scan did start
            'Check the status
            ulstat = Daqboard.GetStatus(CTRStatus, CurCount, CurIndex, MccDaq.FunctionType.CtrFunction)
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
                errhandler(ulstat)
                Exit Sub
            End If

            lblCurCount.Text = CurCount.ToString()
            lblCurIndex.Text = CurIndex.ToString()

            tmrEncoderCounter.Enabled = True
        End If

    End Sub

    Public Sub ModeSetup()
        'The USB-QUAD08 has many modes of operation within Encoder mode.
        'Encoder mode is a base mode but there is are additional offset values depending on features.
        'Some Modes can be combined, but in this example, all modes are demonstrated individually (except InvertGate).
        'Feel free to mix and match different mode parameters of Totalize to get the result you need.
        Mode = MccDaq.CounterMode.Encoder
        Select Case cmboMode.SelectedIndex
            Case 0
                Mode = Mode + MccDaq.CounterMode.EncoderModeX1
            Case 1
                Mode = Mode + MccDaq.CounterMode.EncoderModeX2
            Case 2
                Mode = Mode + MccDaq.CounterMode.EncoderModeX4
        End Select

        'If any options are selected, enable it, and any other feature needed to make it operate.
        If rbuClearOnZOn.Checked Then Mode += MccDaq.CounterMode.EncoderModeClearOnZOn

        If rbuLatchOnZ.Checked Then Mode += MccDaq.CounterMode.EncoderModeLatchOnZ

        If rbuNoRecycleOn.Checked Then
            Mode += MccDaq.CounterMode.NoRecycleOn
            ulstat = Daqboard.CLoad(MaxLimitRegister, Convert.ToInt16(txtMaxLimitRegValue.Text))
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
                errhandler(ulstat)
                Exit Sub
            End If
        End If

        If rbuRangeLimitOn.Checked Then
            Mode += MccDaq.CounterMode.RangeLimitOn
            ulstat = Daqboard.CLoad(MaxLimitRegister, Convert.ToInt16(txtMaxLimitRegValue.Text))
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
                errhandler(ulstat)
                Exit Sub
            End If
        End If

    End Sub

    Private Sub tmrEncoderCounter_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles tmrEncoderCounter.Tick

        ulstat = Daqboard.GetStatus(CTRStatus, CurCount, CurIndex, MccDaq.FunctionType.CtrFunction)
        If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
            errhandler(ulstat)
            Exit Sub
        End If

        lblCurCount.Text = CurCount.ToString()
        lblCurIndex.Text = CurIndex.ToString()
        If CTRStatus = MccDaq.MccBoard.Running Then lblModeStatus.Text = "Running"

        'At every timer tick, determine if there is new data available. 
        'Figure out where you are now versus where you where at the last iteration 
        'If new data is available, copy the new data from the buffer to a local array for processing.
        'If not, exit the Sub and wait for next Tick event.

        If CurIndex > numSamples Then      'get the lower half of the buffer
            If CTRHandle = 0 Then Stop
            If lastPass = "Lower" Then Exit Sub
            lastPass = "Lower"
            lbRawCounterData.Items.Clear()



            ulstat = MccDaq.MccService.WinBufToArray32(CTRHandle, uiDataArray, 0, CInt(numSamples / 2)) 'Ctr32bit
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
                errhandler(ulstat)
                Exit Sub
            End If

        Else          'get upper half of buffer
            If lastPass = "Upper" Then Exit Sub
            lastPass = "Upper"
            lbRawCounterData.Items.Clear()

            
            ulstat = MccDaq.MccService.WinBufToArray32(CTRHandle, uiDataArray, CInt(numSamples / 2), CInt(numSamples / 2)) 'Ctr32bit
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
                errhandler(ulstat)
                Exit Sub
            End If
        End If

        '...Here is where you do something useful with the data.
        'For this example, we are displaying the first element, 
        'showing the first 100 readings of the scan,
        'calculating if the encoder has stopped or count direction.

        lblCounterValueRead.Text = uiDataArray(0)
        For j As Integer = 0 To 99
            lbRawCounterData.Items.Add(uiDataArray(j))
        Next

        'find direction and get 1 value to display on the form
        If uiDataArray(0) = uiDataArray(numSamples / 2 - 1) Then
            lblDirectionUD.Text = "STOPPED"
        End If
        If uiDataArray(0) > uiDataArray(numSamples / 2 - 1) Then
            lblDirectionUD.Text = "DOWN"
        End If
        If uiDataArray(0) < uiDataArray(numSamples / 2 - 1) Then
            lblDirectionUD.Text = "UP"
        End If

        'after each pass of data manipulation, check to see if the scan is still running.
        'If it is, then skip this part, if it is not running any longer 
        'here is a routine to stop the scan, free the buffer, etc.
        If (CTRStatus = MccDaq.MccBoard.Idle) Then
            btnStartStop.Text = "Start"
            tmrEncoderCounter.Enabled = False
            ulstat = Daqboard.StopBackground(MccDaq.FunctionType.AiFunction)
            lblModeStatus.Text = "Idle"
            ulstat = MccDaq.MccService.WinBufFreeEx(CTRHandle) ' Free up memory for use by other programs
            If ulstat.Value <> MccDaq.ErrorInfo.ErrorCode.NoErrors Then
                errhandler(ulstat)
                Exit Sub
            End If
        End If

    End Sub

    Public Function SelectCounter(ByVal nudCounterNumValue As Int32) As Int32
        'This example will let you use any one counter.  
        'If you want to use just one counter, just put the 2 lines for that counter
        'where you see "SelectCounter().
        Select Case nudCounterNumValue
            Case 0
                MccCounter = MccDaq.CounterRegister.LoadReg0
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg0
            Case 1
                MccCounter = MccDaq.CounterRegister.LoadReg1
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg1
            Case 2
                MccCounter = MccDaq.CounterRegister.LoadReg2
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg2
            Case 3
                MccCounter = MccDaq.CounterRegister.LoadReg3
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg3
            Case 4
                MccCounter = MccDaq.CounterRegister.LoadReg4
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg4
            Case 5
                MccCounter = MccDaq.CounterRegister.LoadReg5
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg5
            Case 6
                MccCounter = MccDaq.CounterRegister.LoadReg6
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg6
            Case 7
                MccCounter = MccDaq.CounterRegister.LoadReg7
                MaxLimitRegister = MccDaq.CounterRegister.MaxLimitReg7
        End Select

        Return MccCounter
    End Function

    Public Sub errhandler(ByVal ulstat As MccDaq.ErrorInfo)
        'Generic UL error handler
        tmrEncoderCounter.Enabled = False
        MessageBox.Show(ulstat.Message, "Universal Library Error ", _
                   MessageBoxButtons.OK, MessageBoxIcon.Error)
        lblModeStatus.Text = "Idle"
        btnStartStop.Text = "Start"
        ulstat = Daqboard.StopBackground(MccDaq.FunctionType.CtrFunction)
        ulstat = MccDaq.MccService.WinBufFreeEx(CTRHandle) ' Free up memory for use by other programs
    End Sub

    Private Sub btnEnd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEnd.Click
        End
    End Sub

    '******************************************************************************************************************
    '*Everything from here down is used to control how the program enables and disables features selected by you when *
    '*you run the program, or when you right click on a radio button (encoder option) or any CInScan option.          *
    '*You can ignore everything from here down, unless you want to see how I created the pop up help, etc.            *
    '******************************************************************************************************************

    Private Sub rbuLatchOnZ_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuLatchOnZ.CheckedChanged
        lblMaxLimitRegValue.Visible = False
        txtMaxLimitRegValue.Visible = False

        btnCounterClear.Visible = False
    End Sub

    Private Sub rbuClearOnZOn_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuClearOnZOn.CheckedChanged
        lblMaxLimitRegValue.Visible = False
        txtMaxLimitRegValue.Visible = False

        btnCounterClear.Visible = False
    End Sub

    Private Sub rbuRangeLimitOn_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuRangeLimitOn.CheckedChanged

        lblMaxLimitRegValue.Visible = True
        txtMaxLimitRegValue.Visible = True

        btnCounterClear.Visible = False

    End Sub

    Private Sub rbuNoRecycleOn_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuNoRecycleOn.CheckedChanged
        btnCounterClear.Visible = True

        lblMaxLimitRegValue.Visible = True
        txtMaxLimitRegValue.Visible = True
    End Sub

    Private Sub rbuModuloNOn_CheckedChanged(sender As System.Object, e As System.EventArgs)

        lblMaxLimitRegValue.Visible = True
        txtMaxLimitRegValue.Visible = True

        btnCounterClear.Visible = False

    End Sub

    Private Sub rbuNOP_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles rbuNOP.CheckedChanged
        lblMaxLimitRegValue.Visible = False
        txtMaxLimitRegValue.Visible = False

        btnCounterClear.Visible = False

        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg0)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg1)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg2)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg3)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg4)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg5)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg6)
        ulstat = Daqboard.CClear(MccDaq.CounterRegister.MaxLimitReg7)

    End Sub

    Private Sub rbuLatchOnZ_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuLatchOnZ.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CConfigScan() LatchOnZOn option:" + _
           vbCrLf + _
           vbCrLf + "Selects the Encoder Z mapped signal to latch the counter outputs. This allows the user to know the exact counter value when an edge is present on another counter."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuClearOnZOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuClearOnZOn.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CConfigScan() ClearOnZOn option:" + _
           vbCrLf + _
           vbCrLf + "The counter is cleared on the rising edge of the Index (Z) input. By default, the ClearOnZ option is off, and the counter is not cleared."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuRangeLimitOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuRangeLimitOn.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CConfigScan() RangeLimitOn option:" + _
           vbCrLf + _
           vbCrLf + "Enables Range Limit counting mode. In Range Limit mode, an upper and lower limit is set, mimicking limit switches in the mechanical counterpart." + _
                "The upper limit is set by loading the max limit register with the CLoad, CLoad32, or CLoad64 functions." + _
                "The lower limit is always 0. When counting up, the counter freezes whenever the count reaches the value that was loaded into the max limit register." + _
                vbCrLf + _
                vbCrLf + "Once selected a Text Box will appear where you can enter a value for the MaxCountReg Value."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuNoRecycleOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuNoRecycleOn.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CConfigScan() NoRecycleOn option:" + _
           vbCrLf + _
           vbCrLf + "Enables Non-recycle counting mode. In Non-recycle mode, the counter is disabled whenever a count" + _
                "overflow or underflow takes place. The counter is re-enabled when a clear or a load operation is performed on the counter." + _
                vbCrLf + _
                vbCrLf + "Once selected a Clear/Reset counter button and MaxCountReg box will appear."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuModuloNOn_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs)
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then

            HelpInfo.txtHelpInfo.Text = "CConfigScan() ModuloNOn option:" + _
            vbCrLf + _
            vbCrLf + "In Modulo-N mode, an upper limit is set by loading the max limit register with a maximum count. When counting up," + _
                " the counter will roll-over to 0 when the maximum count is reached, and then continue counting up. Likewise when counting down, " + _
                "the counter will roll over to the maximum count (in the max limit register) whenever the count reaches 0, and then continue counting down." + _
                vbCrLf + _
                vbCrLf + "Once selected a Text Box will appear where you can enter a value for the MaxCountReg Value."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub rbuNOP_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles rbuNOP.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "No Option:  sets the example to no options selected, and clears the MaxLimitRegister"
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub chkExtClock_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles chkExtClock.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CinScan() External Clock option:" + _
            vbCrLf + _
            vbCrLf +
            "If this option is specified, conversions will be controlled by the signal on the external clock input rather than by the internal pacer clock." + _
            " Each conversion will be triggered on the appropriate edge of the clock input signal (refer to board-specific information in the UL User's Guide). " + _
            "When this option is used the rate parameter is ignored. The sampling rate is dependent on the clock signal. Options for the board will default to a " + _
            "transfer mode that will allow the maximum conversion rate to be attained unless otherwise specified."

            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub chkExtTrigger_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles chkExtTrigger.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CinScan() External Trigger option:" + _
            vbCrLf + _
            vbCrLf +
            "If this option is specified, sampling does not begin until the trigger condition is met. You can set the trigger condition to rising edge, falling edge, or the level of the digital trigger input with the SetTrigger() method. Refer to board-specific information in the UL User's Guide." + _
            vbCrLf + _
            vbCrLf + _
            "To complete the set up of this option, you would need to provide a signal on the External Trigger Input or XTRIG terminal.  As SetTrigger is not implemented in this program, XTRIG requires a rising edge."

            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub chkHighResRate_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles chkHighResRate.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CinScan() High Resolution Rate option:" + _
            vbCrLf + _
            vbCrLf +
            "Acquires data at a high resolution rate. When specified, the rate at which samples are acquired is in 'samples per 1000 seconds per channel'. When this option is not specified, the rate at which samples are acquired is in 'samples per second per channel' (refer to the rate parameter of CInScan in the ULHELP)."

            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub chkContinuous_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles chkContinuous.MouseDown
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CinScan() Continuous scan options:" + _
            vbCrLf + _
            vbCrLf +
            "This option puts the function in an endless loop. Once it collects the required number of samples, it resets to the start of the buffer and begins again. The only way to stop this operation is by using StopBackground() with CtrFunction in the FunctionType argument. You can only use this option with Background so that you remain in control of the program." + _
            vbCrLf + _
            vbCrLf + _
            "By design, this program operates in Background mode.  All other options can be selected."

            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub lblCounterResolution_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs)
        Dim MouseArgs As MouseEventArgs = e
        If MouseArgs.Button = Windows.Forms.MouseButtons.Right Then
            HelpInfo.txtHelpInfo.Text = "CinScan() Counter Resolution options:" + _
            vbCrLf + _
            vbCrLf +
            "Ctr16Bit:  Sets the counter resolution to 16-bits. When using devices that return data in a 16-bit format, create the buffer using WinBufAllocEx()." + _
            vbCrLf + _
             "Ctr32Bit:  Sets the counter resolution to 32-bits. When using devices that return data in a 16-bit format, create the buffer using WinBufAlloc32Ex()." + _
            vbCrLf +
             "Ctr64Bit:  Sets the counter resolution to 64-bits. When using devices that return data in a 16-bit format, create the buffer using WinBufAlloc64Ex()." + _
              vbCrLf + _
            vbCrLf +
            "You use this feature to when deciding how large a number you expect to count before it rolls over to 0.  A 16 bit number will roll over at 65535.  A 32 bit number" + _
            " will roll over at 4294967296, and a 64 bit number will roll over at 18446744073709551616."
            HelpInfo.Show(Me)
        End If
    End Sub

    Private Sub txtMaxLimitRegValue_KeyPress(sender As System.Object, e As System.Windows.Forms.KeyPressEventArgs) Handles txtMaxLimitRegValue.KeyPress
        KeyPressService(sender, e, AllowedCharactersInt)
    End Sub

End Class
